# MachineLearning

> see https://aka.ms/autorest

This is the AutoRest configuration file for MachineLearning.



---
## Getting Started
To build the SDK for MachineLearning, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the MachineLearning API.

``` yaml
openapi-type: arm
```

``` yaml $(package-webservices)
tag: package-webservices-2017-01
```

``` yaml $(package-commitmentPlans)
tag: package-commitmentPlans-2016-05-preview
```

``` yaml $(package-workspaces)
tag: package-workspaces-2016-04
```

### Tag: package-webservices-2017-01

These settings apply only when `--tag=package-webservices-2017-01` is specified on the command line.

``` yaml $(tag) == 'package-webservices-2017-01'
input-file:
- Microsoft.MachineLearning/stable/2017-01-01/webservices.json
```

### Tag: package-commitmentPlans-2016-05-preview

These settings apply only when `--tag=package-commitmentPlans-2016-05-preview` is specified on the command line.

``` yaml $(tag) == 'package-commitmentPlans-2016-05-preview'
input-file:
- Microsoft.MachineLearning/preview/2016-05-01-preview/commitmentPlans.json
```

### Tag: package-workspaces-2016-04

These settings apply only when `--tag=package-workspaces-2016-04` is specified on the command line.

``` yaml $(tag) == 'package-workspaces-2016-04'
input-file:
- Microsoft.MachineLearning/stable/2016-04-01/workspaces.json
```

### Tag: package-webservices-2016-05-preview

These settings apply only when `--tag=package-webservices-2016-05-preview` is specified on the command line.

``` yaml $(tag) == 'package-webservices-2016-05-preview'
input-file:
- Microsoft.MachineLearning/preview/2016-05-01-preview/webservices.json
```


---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_machine_learning']
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

```yaml $(csharp)
csharp:
  azure-arm: true
  payload-flattening-threshold: 1
  license-header: MICROSOFT_MIT_NO_VERSION
  clear-output-folder: true
batch:
  - package-webservices: true
    namespace: Microsoft.Azure.Management.MachineLearning.WebServices
    output-folder: $(csharp-sdks-folder)/MachineLearning/Management.MachineLearning/Generated/WebServices
  - package-commitmentPlans: true
    namespace: Microsoft.Azure.Management.MachineLearning.CommitmentPlans
    output-folder: $(csharp-sdks-folder)/MachineLearning/Management.MachineLearning/Generated/CommitmentPlans
  - package-workspaces: true
    namespace: Microsoft.Azure.Management.MachineLearning.Workspaces
    output-folder: $(csharp-sdks-folder)/MachineLearning/Management.MachineLearning/Generated/Workspaces
```


## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  clear-output-folder: true
```

### Go multi-api

``` yaml $(go) && $(multiapi)
batch:
  - tag: package-webservices-2017-01
  - tag: package-webservices-2016-05-preview
  - tag: package-workspaces-2016-04
  - tag: package-commitmentPlans-2016-05-preview
```

### Tag: package-webservices-2017-01 and go

These settings apply only when `--tag=package-webservices-2017-01 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-webservices-2017-01' && $(go)
namespace: webservices
output-folder: $(go-sdk-folder)/services/machinelearning/mgmt/2017-01-01/webservices
```

### Tag: package-webservices-2016-05-preview and go

These settings apply only when `--tag=package-webservices-2016-05-preview --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-webservices-2016-05-preview' && $(go)
namespace: webservices
output-folder: $(go-sdk-folder)/services/preview/machinelearning/mgmt/2016-05-01-preview/webservices
```

### Tag: package-workspaces-2016-04 and go

These settings apply only when `--tag=package-workspaces-2016-04 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-workspaces-2016-04' && $(go)
namespace: workspaces
output-folder: $(go-sdk-folder)/services/machinelearning/mgmt/2016-04-01/workspaces
```

### Tag: package-commitmentPlans-2016-05-preview and go

These settings apply only when `--tag=package-commitmentPlans-2016-05-preview --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-commitmentPlans-2016-05-preview' && $(go)
namespace: commitmentplans
output-folder: $(go-sdk-folder)/services/preview/machinelearning/mgmt/2016-05-01-preview/commitmentplans
```


## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.machinelearning
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-machinelearning
```

# Validation

Since this RP has no unique default package, iterate over all of them for validation:

``` yaml $(validation)
batch:
  - package-webservices: true
  - package-commitmentPlans: true
  - package-workspaces: true
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-webservices-2017-01
  - tag: package-commitmentPlans-2016-05-preview
  - tag: package-webservices-2016-05-preview
  - tag: package-workspaces-2016-04
```

### Tag: package-webservices-2017-01 and java

These settings apply only when `--tag=package-webservices-2017-01 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-webservices-2017-01' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.machinelearning.v2017_01_01
  output-folder: $(azure-libraries-for-java-folder)/machinelearning/resource-manager/v2017_01_01
regenerate-manager: true
generate-interface: true
```

### Tag: package-commitmentPlans-2016-05-preview and java

These settings apply only when `--tag=package-commitmentPlans-2016-05-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-commitmentPlans-2016-05-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.machinelearning.v2016_05_01_preview
  output-folder: $(azure-libraries-for-java-folder)/machinelearning/resource-manager/v2016_05_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-webservices-2016-05-preview and java

These settings apply only when `--tag=package-webservices-2016-05-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-webservices-2016-05-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.machinelearning.v2016_05_01_preview
  output-folder: $(azure-libraries-for-java-folder)/machinelearning/resource-manager/v2016_05_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-workspaces-2016-04 and java

These settings apply only when `--tag=package-workspaces-2016-04 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-workspaces-2016-04' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.machinelearning.v2016_04_01
  output-folder: $(azure-libraries-for-java-folder)/machinelearning/resource-manager/v2016_04_01
regenerate-manager: true
generate-interface: true
```


